@@ -11,13 +11,14 @@
 #'
 #' @usage GetproteinNetwork(ProteinAccList)
 #'
-#' @author Mohmed Soudy and Ali Mostafa
+#' @author Mohmed Soudy \email{Mohamed.soudy@57357.com} and Ali Mostafa \email{ali.mo.anwar@std.agr.cu.edu.eg}
 #'
 #' @export
 GetproteinNetwork <- function(ProteinAccList , directorypath = NULL)
 {
   pdf(paste0(directorypath , "/","Protin Network.pdf"))
   baseUrl <- "https://string-db.org/api/image/network?identifiers="
+  Accessions <- NULL
   for (identifier in ProteinAccList)
   {
     ProteinString <- paste0(baseUrl , identifier)
@@ -25,15 +26,20 @@ GetproteinNetwork <- function(ProteinAccList , directorypath = NULL)
     if (Request$status_code == 200)
     {
       Network <- image_read(ProteinString)
+      ProteinName <- GetProteinAnnontate(identifier,"protein names")
       plot(Network)
+      title(list(paste0(identifier ,":" ,  ProteinName),cex = 0.4, font = 1))
+      Accessions <- c(Accessions , identifier);
     }else{
-      dev.off()
-      HandleBadRequests(Request$status_code)
-      pdf(paste0(directorypath , "/","Protin Network.pdf"))
+      print(paste0(identifier , " Not Found on Stringdb"))
     }
   }
-  ProteinList <- paste0(baseUrl,ProteinAccList , collapse = "%0d" , "&add_color_nodes=20&network_flavor=actions&block_structure_pics_in_bubbles=1")
+  ProteinList <- paste0(Accessions , collapse = "%0d")
+  ProteinList <- paste0(baseUrl,ProteinList)
+  ProteinList <- paste0(ProteinList , "&network_flavor=actions&block_structure_pics_in_bubbles=1")
   WholeNetwork <- image_read(ProteinList)
   plot(WholeNetwork)
+  title(list("Whole Protein Network", cex = 1,
+             col = "black", font = 1))
   dev.off()
 }
